import bcrypt from "bcryptjs";
import UserRepository from "../repositories/UserRepository";
import CharacterRepository from "../repositories/CharacterRepository";

class UserService
{
    async login(username: string, password: string): Promise<boolean | any> {
        const user = await UserRepository.getByUsername(username);
        if (!user) {
            return false;
        }

        const passwordMatch = await bcrypt.compare(password, user.password);
        if (!passwordMatch) {
            return false;
        }

        return user;
    }

    async register(username: string, password: string): Promise<boolean | any> {
        const user = await UserRepository.getByUsername(username);
        if (user) {
            return false;
        }

        const hashedPassword = await bcrypt.hash(password, 10);
        const newUser = await UserRepository.create(username, hashedPassword);

        // @TODO: Remove this logic from here and move it to the character creation part wherever that'll be
        const newCharacter = await CharacterRepository.create(newUser.id, newUser.username);

        return newUser
    }
}

export default UserService;